﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace howto_treeview_tooltips
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        // Build the TreeView.
        private void Form1_Load(object sender, EventArgs e)
        {
            const int imFactory = 0;
            const int imGroup = 1;
            const int imPerson = 2;

            // Load TreeView data.
            TreeNode factory, group, person;
            factory = AddTreeViewNode(trvOrg.Nodes, "R & D", imFactory, new FactoryData("Factory: R & D"));
            group = AddTreeViewNode(factory.Nodes, "Engineering", imGroup, new GroupData("Group: Engineering"));
            person = AddTreeViewNode(group.Nodes, "Cameron, Charlie", imPerson, new PersonData("Person: Cameron, Charlie", "Alpha", "Beta"));
            person = AddTreeViewNode(group.Nodes, "Davis, Debbie", imPerson, new PersonData("Person: Davos, Debbie", "Alpha", "Gamma"));

            group = AddTreeViewNode(factory.Nodes, "Test", imGroup, new GroupData("Group: Test"));
            person = AddTreeViewNode(group.Nodes, "Able, Andy", imPerson, new PersonData("Person: Able, Andy", "SPCD", "Feldspar", "Flicker"));
            person = AddTreeViewNode(group.Nodes, "Baker, Betty", imPerson, new PersonData("Person: Baker, Betty", "Pickle"));

            factory = AddTreeViewNode(trvOrg.Nodes, "Sales & Support", imFactory, new FactoryData("Factory: Sales & Support"));
            group = AddTreeViewNode(factory.Nodes, "Showroom Sales", imGroup, new GroupData("Group: Showroom Sales"));
            person = AddTreeViewNode(group.Nodes, "Gaines, Gina", imPerson, new PersonData("Person: Gaines, Gina", "SalesForce1"));

            group = AddTreeViewNode(factory.Nodes, "Field Service", imGroup, new GroupData("Group: Field Service"));
            person = AddTreeViewNode(group.Nodes, "Helms, Harry", imPerson, new PersonData("Person: Helms, Harry", "Bookster", "Tetrup"));
            person = AddTreeViewNode(group.Nodes, "Ives, Irma", imPerson, new PersonData("Person: Ives, Irma"));
            person = AddTreeViewNode(group.Nodes, "Jackson, Josh", imPerson, new PersonData("Person: Jackson, Josh", "MicroCosmos"));

            group = AddTreeViewNode(factory.Nodes, "Customer Support", imGroup, new GroupData("Group: Customer Support"));
            person = AddTreeViewNode(group.Nodes, "Klug, Karl", imPerson, new PersonData("Person: Klug, Karl", "MicroCosmos", "Anabash"));
            person = AddTreeViewNode(group.Nodes, "Landau, Linda", imPerson, new PersonData("Person: Landau, Linda", "Wintegration"));

            trvOrg.ExpandAll();
        }

        // Add a new node to the collection.
        private TreeNode AddTreeViewNode(TreeNodeCollection parent_nodes, string text, int image_index, object tag_object)
        {
            TreeNode new_node = parent_nodes.Add(text);
            new_node.ImageIndex = image_index;
            new_node.SelectedImageIndex = image_index;
            new_node.Tag = tag_object;
            return new_node;
        }

        // Display the appropriate tooltip.
        private TreeNode old_node = null;
        private void trvOrg_MouseMove(object sender, MouseEventArgs e)
        {
            // Find the node under the mouse.
            TreeNode node_here = trvOrg.GetNodeAt(e.X, e.Y);
            if (node_here == old_node) return;
            old_node = node_here;

            // See if we have a node.
            if (old_node == null)
            {
                ttOrg.SetToolTip(trvOrg, "");
            }
            else
            {
                // Get this node's object data.
                if (node_here.Tag is FactoryData)
                {
                    FactoryData factory_data = node_here.Tag as FactoryData;
                    ttOrg.SetToolTip(trvOrg, factory_data.Name);
                }
                else if (node_here.Tag is GroupData)
                {
                    GroupData group_data = node_here.Tag as GroupData;
                    ttOrg.SetToolTip(trvOrg, group_data.Name);
                }
                else if (node_here.Tag is PersonData)
                {
                    PersonData person_data = node_here.Tag as PersonData;
                    ttOrg.SetToolTip(trvOrg, person_data.Name);
                }
            }
        }
    }
}
